@@ -58,13 +58,6 @@ Class representation of atom bonds.
    Bond
    Bonds
 
-Classes for structure analysis
-
-.. autosummary::
-   :toctree: generated/
-
-   NeighborAtoms
-
 Classes for molecular dynamics simulations:
 
 .. autosummary::
@@ -77,19 +70,20 @@ Classes for molecular dynamics simulations:
 from __future__ import absolute_import, division, print_function
 __docformat__ = 'restructuredtext en'
 
+#from ._base import *
 from ._atom import *
 from ._atoms import *
-#from ._base import *
-from ._bond import *
-from ._bonds import *
 from ._extended_atom import *
 from ._extended_atoms import *
 from ._kdtree_atom import *
 from ._kdtree_atoms import *
-from ._neighbor_atoms import *
 from ._poav_atom import *
 from ._poav_atoms import *
 from ._structure_atoms import *
+
+from ._bond import *
+from ._bonds import *
+
 from ._trajectory import *
 
 __all__ = [s for s in dir() if not s.startswith('_')]
