@@ -2,9 +2,10 @@
 from __future__ import division, print_function, absolute_import
 
 
-def configuration(parent_package='', top_path=None):
+def configuration(parent_package='core', top_path=None):
     from numpy.distutils.misc_util import Configuration
     config = Configuration('math', parent_package, top_path)
+    config.add_data_dir('tests')
     return config
 
 if __name__ == '__main__':
