@@ -7,8 +7,8 @@ MWNT Bundle Generator (:mod:`sknano.generators._mwnt_bundle_generator`)
 .. currentmodule:: sknano.generators._mwnt_bundle_generator
 
 """
-from __future__ import absolute_import, division, print_function
-import six
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 __docformat__ = 'restructuredtext en'
 
 from sknano.core import pluralize
@@ -21,7 +21,7 @@ __all__ = ['MWNTBundleGenerator']
 
 class MWNTBundleGenerator(NanotubeBundleGeneratorMixin, MWNTBundle,
                           MWNTGenerator):
-    six.u("""Class for generating multi-walled nanotube bundles.
+    """Class for generating multi-walled nanotube bundles.
 
     .. versionadded:: 0.2.20
 
@@ -96,7 +96,7 @@ class MWNTBundleGenerator(NanotubeBundleGeneratorMixin, MWNTBundle,
 
     .. image:: /images/5shell_mwnt_4040_outer_Ch_hcp_7tube_hexagon-01.png
 
-    """)
+    """
     def __init__(self, autogen=True, **kwargs):
 
         super(MWNTBundleGenerator, self).__init__(autogen=False, **kwargs)
